==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/REPORTPERMISSIONS.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PERM" type="{http://schemas.datastream.net/MP_fields}REPORT_PERMISSION_Type" maxOccurs="4"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "perm"
})
@XmlRootElement(name = "REPORTPERMISSIONS")
public class REPORTPERMISSIONS {

    @XmlElement(name = "PERM", required = true)
    @XmlSchemaType(name = "string")
    protected List<REPORT_PERMISSION_Type> perm;

    /**
     * Gets the value of the perm property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the perm property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPERM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link REPORT_PERMISSION_Type }
     * 
     * 
     */
    public List<REPORT_PERMISSION_Type> getPERM() {
        if (perm == null) {
            perm = new ArrayList<REPORT_PERMISSION_Type>();
        }
        return this.perm;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/REPORTPERMISSIONS.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PERM" type="{http://schemas.datastream.net/MP_fields}REPORT_PERMISSION_Type" maxOccurs="4"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "perm"
})
@XmlRootElement(name = "REPORTPERMISSIONS")
public class REPORTPERMISSIONS {

    @XmlElement(name = "PERM", required = true)
    @XmlSchemaType(name = "string")
    protected List<REPORT_PERMISSION_Type> perm;

    /**
     * Gets the value of the perm property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the perm property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPERM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link REPORT_PERMISSION_Type }
     * 
     * 
     */
    public List<REPORT_PERMISSION_Type> getPERM() {
        if (perm == null) {
            perm = new ArrayList<REPORT_PERMISSION_Type>();
        }
        return this.perm;
    }

}
